@@ -125,14 +125,13 @@ void rpc2_PrintSLEntry(struct SL_Entry *slPtr, FILE *tFile)
 		    break;
 	
 	case REQ:
-		    fprintf(tFile, "\tElementType = REQ  Packet = 0x%lx  Filter==>  ",
-			    (long)slPtr->Packet);
+		    fprintf(tFile, "\tElementType = REQ  Packet = %p  Filter==>  ", slPtr->data);
 		    rpc2_PrintFilter(&slPtr->Filter, tFile);
 		    break;
 	
 	case OTHER:
-		    fprintf(tFile, "\tElementType = OTHER  Conn = %#x  Packet = 0x%lx\n",
-			    slPtr->Conn, (long)slPtr->Packet);
+		    fprintf(tFile, "\tElementType = OTHER  Conn = %#x  Packet = %p\n",
+			    slPtr->Conn, slPtr->data);
 		    break;
 
 	default:
@@ -190,16 +189,11 @@ void rpc2_PrintHEntry(struct HEntry *hPtr, FILE *tFile)
     rpc2_printaddrinfo(hPtr->Addr, tFile);
 
     fprintf(tFile, "\tLastWord = %ld.%06ld\n", hPtr->LastWord.tv_sec, hPtr->LastWord.tv_usec);
-    fprintf(tFile, "\tRTT = %ld.%03ld, RTTvar = %ld.%03ld\n",
-	    hPtr->RTT >> RPC2_RTT_SHIFT,
-	    hPtr->RTT % ((1 << RPC2_RTT_SHIFT) - 1),
-	    hPtr->RTTVar >> RPC2_RTTVAR_SHIFT,
-	    hPtr->RTTVar % ((1 << RPC2_RTTVAR_SHIFT) - 1));
-    fprintf(tFile, "\tByteRate = %ld.%03ld ns/B, BRvar = %ld.%03ld\n",
-	    hPtr->BR >> RPC2_BR_SHIFT,
-	    hPtr->BR % ((1 << RPC2_BR_SHIFT) - 1),
-	    hPtr->BRVar >> RPC2_BRVAR_SHIFT,
-	    hPtr->BRVar % ((1 << RPC2_BRVAR_SHIFT) - 1));
+    fprintf(tFile, "\tRTT = %ld.%03ld\n",
+	    hPtr->RTT >> RPC2_RTT_SHIFT, hPtr->RTT % ((1 << RPC2_RTT_SHIFT) - 1));
+
+    fprintf(tFile, "\tBandwidth = out: %u:%u B/s, in: %u:%u B/s\n",
+	    hPtr->BWlo_out, hPtr->BWhi_out, hPtr->BWlo_in, hPtr->BWhi_in);
 
     PrintNetLog("RPC2", hPtr->RPC2_NumEntries, hPtr->RPC2_Log, tFile);
     PrintNetLog("SE",   hPtr->SE_NumEntries,   hPtr->SE_Log,   tFile);
@@ -210,7 +204,6 @@ void rpc2_PrintHEntry(struct HEntry *hPtr, FILE *tFile)
 
 void rpc2_PrintCEntry(struct CEntry *cPtr, FILE *tFile)
 {
-    long i;
     if (tFile == NULL) tFile = rpc2_logfile;	/* it's ok, call-by-value */
     fprintf(tFile, "MyAddr: %p\n\tNextEntry = %p  PrevEntry = %p  MagicNumber = %s  Role = %s  State = ",
 	cPtr, cPtr->connlist.next, cPtr->connlist.prev,
@@ -247,19 +240,9 @@ void rpc2_PrintCEntry(struct CEntry *cPtr, FILE *tFile)
 
     fprintf(tFile, "\n\tUniqueCID = %#x  NextSeqNumber = %d  PeerHandle = %#x\n\tPrivatePtr = %p  SideEffectPtr = %p\n",
     	cPtr->UniqueCID, cPtr->NextSeqNumber, cPtr->PeerHandle, cPtr->PrivatePtr, cPtr->SideEffectPtr);
-	
-    fprintf(tFile, "\tLowerLimit = %lu usec  %s = %ld  %s = %ld  Retries = %ld\n",
-	    cPtr->LowerLimit,
-	    TestRole(cPtr, CLIENT) ? "RTT" : (TestRole(cPtr, SERVER) ? "TimeEcho" : "?????"),
-	    cPtr->RTT, 
-	    TestRole(cPtr, CLIENT) ? "RTTVar" : (TestRole(cPtr, SERVER) ? "RequestTime" : "?????"),
-	     cPtr->RTTVar,  cPtr->Retry_N);
 
-    fprintf(tFile, "\tRetry_Beta[0] = %ld.%0ld  (timeout)\n",
-	    cPtr->Retry_Beta[0].tv_sec, cPtr->Retry_Beta[0].tv_usec);
-    for (i = 1; i < cPtr->Retry_N+2; i++) 
-	    fprintf(tFile, "\tRetry_Beta[%ld] = %ld.%0ld\n",
-		    i, cPtr->Retry_Beta[i].tv_sec, cPtr->Retry_Beta[i].tv_usec);
+    fprintf(tFile, "\tKeepAlive = %ld.%0ld  (timeout)\n",
+	    cPtr->KeepAlive.tv_sec, cPtr->KeepAlive.tv_usec);
 
     fprintf(tFile, "\tHeldPacket = %p  PeerUnique = %d\n",
     	cPtr->HeldPacket, cPtr->PeerUnique);
